#    Society Self-Service
#    Copyright © 2018-2019  Yingtong Li (RunasSudo)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.

from django.core.management.base import BaseCommand, CommandError

from ssmain.email import Emailer
import ssmembership.models

class Command(BaseCommand):
	help = 'Send Markdown emails'
	
	def add_arguments(self, parser):
		parser.add_argument('template', help='Template name')
		parser.add_argument('subject', help='Email subject')
		parser.add_argument('ids', nargs='*', type=int, help='Members with ID numbers equal to these values will be emailed (default all)')
	
	def handle(self, *args, **options):
		members = ssmembership.models.Member.objects.all()
		
		if len(options['ids']) > 0:
			members = [member for member in members if member.id in options['ids']]
		else:
			raise Exception('Must provide IDs')
		
		emailer = Emailer()
		for member in members:
			self.stdout.write('Emailing {} at {}'.format(member.id, member.email))
			emailer.send_mail([member.email], options['subject'], 'ssmembership/email/' + options['template'] + '.md', {})
